pro aot_ext,chan,delta_ozone,delta_no2,csite,mode,y_input,m_input,d_input,time,am,year_count,pressure_corr,rel_press,ifit,cimel_chan,l0_fit,l1_fit,l2_fit, $	; input
	aeronet_wav_air,aeronet_aot,  ln_wav_mfrsr,aot_mfrsr, aer340cor,aer380cor,aer440cor,aer500cor, delta_aot_fit,sigma_aot_fit


;		WARNING

;		MODIFIED
;       12/07/12 - include delta_ozone[atm-cm] ,delta_no2 [atm-cm] for AERONET AOT corrections when no2_measured NE  no2_aeronet OR ozone_measured NE  ozone_aeronet
;	07/20/11 - insert CIMEL specific wavelengths : aeronet_wav_air from the merged file          
;	03/15/10 - re-process period Dec 2009-02/2010                                                
;	02/17/08 - re-process period Feb 2007-2008                                                   
;	06/03/07 - add period Feb 2007-   to calibration                                                 
;	04/25/06 - add Brewer AOT linear lsf interpolation                                                 
;	05/20/05 - 3 wavelength lagrangian interpolation (cimel_chan=3)  l0_fit,l1_fit,l2_fit   
;	05/10/05 - to prevent non-positive aer340cor,aer380cor,aer440cor,aer500cor               
;	03/08/05 - to add V0 correction (CIMEL and channel specific)                             
;	03/04/05 - to output corrcted AERONET AOT (aer340cor,aer380cor,aer440cor,aer500cor)
;	02/28/05 - to generalize linear interpolation for any 2 wavelengths: l0_fit,l1_fit

;		INPUT
; n0minal AERONET wavelengths   340 380 440 500 670 870 1020
; aeronet_wav_air               [0, 1,   2,  3,  4,  5,    6] 	i CIMEL exact center wavelengths (in air)
; aeronet_aot[0,1,2,3,4,5,6] 	i uncorrected AERONET AOTs (from the web site only time interpolated to MFRSR measurements)
; l0_fit,l1_fit		i 	linear interpolation wavelength indices (0-340, 1-380, 2-440, 3-500)
; ln_wav_mfrsr		i  ln all wavelengths within boundaries of the UV-MFRSR channel currently calibrated (lmin , ...,lmax)
				;print,'aot_ext.pro: wav_mfrsr:',exp(ln_wav_mfrsr)

;		OUTPUT
; aot_mfrsr[nlam]  o corrected aeronet_aot(...)  extrapolated to all vac wavelengths within calibrated MFRSR channel

; aer340cor     o  corrected aeronet_aot(0)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 340nm filter
; aer380cor     o  corrected aeronet_aot(1)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 380nm filter
; aer440cor     o  corrected aeronet_aot(2)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 440nm filter
; aer500cor     o  corrected aeronet_aot(3)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 500nm filter
; aer670cor     o  corrected aeronet_aot(4)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 670nm filter
; aer870cor     o  corrected aeronet_aot(5)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 870nm filter
; aer1020cor     o  corrected aeronet_aot(6)  (for pressure, V0 , NO2, etc) referred to central wavelength (l_cent) of CIMEL 1020nm filter


nlam=n_elements(ln_wav_mfrsr)
aot_mfrsr=dblarr(nlam)


;			Future possible AERONET AOT corrections

;No corrections to AERONET AOT  ( inversion 2 AERONET AOT there is good pressure correction as well as climatological NO2 correction)
;	!!!! any corrections to AERONET AOT require consistent corrections to tau_ray, tau_ozone, tau_no2 in get_tot_cp.pro
aer340cor     =aeronet_aot(0)
aer380cor     =aeronet_aot(1)
aer440cor     =aeronet_aot(2)
aer500cor     =aeronet_aot(3)
aer670cor     =aeronet_aot(4)
aer870cor     =aeronet_aot(5)
aer1020cor    =aeronet_aot(6)

;print,'Original AERONET AOTs',aeronet_aot
;print,'delta_no2=',delta_no2, '	delta_ozone=',delta_ozone

;	Ozone and NO2 correction should be done consistently with get_tot_cp.pro 
;print,'Ozone and NO2 corrections: delta_no2 and delta_ozone should be in [atm-cm]'
aer340cor     =aeronet_aot(0) +  delta_no2*9.94   + delta_ozone*0.023  ;  !!! No2 [Vandelie]  and ozone [Daumont] absorption coefficients [atm_cm-1] are averaged over AERONET 340 flter installed in UV-MFRSR582 in 2010 
aer380cor     =aeronet_aot(1) +  delta_no2*14.85  + delta_ozone*0.00014; !!! No2 [Vandelie]  and ozone [Daumont] absorption coefficients [atm_cm-1] are averaged over AERONET 380 flter installed in UV-MFRSR582 in 2010 
aer440cor     =aeronet_aot(2) +  delta_no2*13.27  + delta_ozone*0.00262; !!! No2 [Vandelie]  and ozone [Daumont] absorption coefficients [atm_cm-1] are averaged over AERONET 440 flter installed in UV-MFRSR582 in 2010 
aer500cor     =aeronet_aot(3) +  delta_no2*6.0487 + delta_ozone*0.0323 ; !!! No2 [Vandelie]  and ozone [Daumont] absorption coefficients [atm_cm-1] are averaged over rectangular 10nm SRF 
;aer670cor     =aeronet_aot(4) +  delta_no2*?????? + delta_ozone*?????? ; !!! Check the constant is No2 absorption coefficient [atm_cm-1] averaged over AERONET 500 spectral channel
;aer870cor     =aeronet_aot(5) +  delta_no2*?????? + delta_ozone*?????? ; !!! Check the constant is No2 absorption coefficient [atm_cm-1] averaged over AERONET 500 spectral channel
;aer1020cor     =aeronet_aot(6) +  delta_no2*?????? + delta_ozone*?????? ; !!! Check the constant is No2 absorption coefficient [atm_cm-1] averaged over AERONET 500 spectral channel
;print,'corrected AOTs',aer340cor,aer380cor,aer440cor,aer500cor,aer670cor,aer870cor,aer1020cor

;	Pressure correction is not needed with version 2 AERONET AOT
;delta_pres=(1.0 - rel_press/pres_aeronet) 	;  Obsolete:   Only for version 1 AERONET AOT specific pressure and V0 correction
;IF pressure_corr eq 'yes' THEN BEGIN		
;aer340cor     =aer340cor +tr340*delta_pres > 0.0001	; if aer340cor < 0.0001 then aer340cor=0.0001
;aer380cor     =aer380cor +tr380*delta_pres > 0.0001	; if aer380cor < 0.0001 then aer340cor=0.0001
;aer440cor     =aer440cor +tr440*delta_pres > 0.0001	; if aer440cor < 0.0001 then aer340cor=0.0001
;aer500cor     =aer500cor +tr500*delta_pres > 0.0001	; if aer500cor < 0.0001 then aer340cor=0.0001
;ENDIF		 				; END: Pressure correction of AERONET AOT data


aot_mode='aeronet'

CASE  aot_mode OF
'aeronet': BEGIN

;		Wavelength extrapolation of AERONET AOTs at instrument specific wavelengths 

ln_aot=alog([aer340cor,aer380cor,aer440cor,aer500cor] )           ; Corrected AERONET AOT
ln_wav=alog(0.1+aeronet_wav_air[0:3])      ; and lam plus 0.1 for vacuum wavelength scale

if ifit eq 2 then begin		; Quadratic spectral interpolation
; ifit=2 and cimel_chan=3  - Lagrangian quadratic extrapolation using l0_fit,l1_fit and l2_fit
; ifit=2 and cimel_chan=4  - quadratic least square extrapolation
IF (cimel_chan eq 4 ) THEN BEGIN
coe_fit=poly_fit(ln_wav,ln_aot,ifit,yfit,/double)		; standard LSF [340,380,440,500]
;yf =coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav
for i=0,nlam-1 do aot_mfrsr(i)=exp(coe_fit(0) + coe_fit(1)*ln_wav_mfrsr(i) + coe_fit(2)*ln_wav_mfrsr(i)*ln_wav_mfrsr(i))
ENDIF


IF (cimel_chan eq 3 ) THEN BEGIN
ind_fit=[l0_fit,l1_fit,l2_fit]
coe_fit=poly_fit(ln_wav(ind_fit),ln_aot(ind_fit),ifit,yfit,/double)		; Lagrange interpolation from [l0_fit,l1_fit,l2_fit]
;yf =coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav
for i=0,nlam-1 do aot_mfrsr(i)=exp(coe_fit(0) + coe_fit(1)*ln_wav_mfrsr(i) + coe_fit(2)*ln_wav_mfrsr(i)*ln_wav_mfrsr(i))
ENDIF

endif else begin	; Linear interpolation (l0_fit,l1_fit)
;	else - linear extrapolation at 2 wavelengths (340, 380), (380,440), (440,500)
coe_fit=dblarr(2)
;		(l0,l1  ):
coe_fit(0)=(ln_aot(l0_fit)*ln_wav(l1_fit)-ln_aot(l1_fit)*ln_wav(l0_fit))/(ln_wav(l1_fit)-ln_wav(l0_fit)) 
coe_fit(1)=(ln_aot(l0_fit)-ln_aot(l1_fit))/(ln_wav(l0_fit)-ln_wav(l1_fit))

;		(340,380):
;coe_fit(0)=(ln_aot(0)*ln_wav(1)-ln_aot(1)*ln_wav(0))/(ln_wav(1)-ln_wav(0)) 
;coe_fit(1)=(ln_aot(0)-ln_aot(1))/(ln_wav(0)-ln_wav(1))
IF (year_count ge 2004.5859) and (year_count lt 2004.753 ) THEN BEGIN
coe_fit(0)=(ln_aot(1)*ln_wav(2)-ln_aot(2)*ln_wav(1))/(ln_wav(2)-ln_wav(1))  ; For CIMEL 303 at UAE need to avoid 340channel 
coe_fit(1)=(ln_aot(1)-ln_aot(2))/(ln_wav(1)-ln_wav(2))	;  linear extrapolation of AERONET [380,440]
ENDIF
for i=0,nlam-1 do aot_mfrsr(i)=exp(coe_fit(0) + coe_fit(1)*ln_wav_mfrsr(i))
endelse
		END

'brewer' : 	BEGIN
print,'aot_ext.pro:   aot_mode=',aot_mode &  print,'Should be aeronet' & stop
		END
ENDCASE

plot_aot_spec,chan,csite,y_input,m_input,d_input,year_count_input,mode,count_day,time,am,aeronet_wav_air[0:3],aeronet_aot[0:3],aer340cor,aer380cor,aer440cor,aer500cor,ifit,delta_aot_fit,sigma_aot_fit,l0_fit,l1_fit

;print,'aot_ext.pro: aot_mfrsr:',aot_mfrsr

return
end
