
pro cctilt,tilt_NS,tilt_EW,chan, year1,month1,day1,hh1,mn1,ss1,tot0,dif0,dir0,sza_i,am_i, $
           vt_corr, vdiff_corr, vdirn_corr, fzenith, airmass

;*******input**********
;tilt_NS, tilt_EW, channel
;year, month, day, hour, minute, second
;total irradiance, diffuse irradiance, direct normal irradiance
;solar zenith angle, air mass factor

;*******output*********
;corrected total irradiance, diffuse irradiance, direct normal irradiance
;corrected solar zenith angle, air mass factor

nobs = n_elements(year1)
vt_corr=fltarr(nobs) & vdirn_corr=fltarr(nobs) & vdiff_corr=fltarr(nobs)
airmass=fltarr(nobs)
zenithN=fltarr(90) & zenithS=fltarr(90) & zenithE=fltarr(90) & zenithW=fltarr(90)
N_CC   =fltarr(90) & S_CC   =fltarr(90) & E_CC=fltarr(90)    & W_CC=fltarr(90)
zenith_new =fltarr(nobs)

if chan eq '368nm' then wv=6
if chan eq '332nm' then wv=5
if chan eq '325nm' then wv=4
if chan eq '317nm' then wv=3
if chan eq '311nm' then wv=2
if chan eq '305nm' then wv=1
if chan eq '440nm' then wv=0

folder ='./'
fdiso  =fltarr(7)
;*****Diffusion correction factor*****
fdiso(0)=1.01989
fdiso(1)=1.00407
fdiso(2)=1.0057
fdiso(3)=1.00674
fdiso(4)=1.00891
fdiso(5)=1.0109
fdiso(6)=1.01951 
;fdiso(*) =1. ;diffuse correction was already done when merged-file was created.


jday = julday_original(month1,day1,year1,hh1,mn1,ss1)

;====================OPEN AND READ COSINE CORRECTION TABLE==================
  temp_tab=fltarr(16,358) & cos_tab=fltarr(358,16)
  openr, 12, folder+'COSTAB_00582_034_2010B.txt'
  readf, 12, temp_tab
  close, 12
  for c=0, 358-1 do cos_tab(c,*) = temp_tab(*,c)
  
;=================================================================================================
;==use subroutine (zensun.pro)
;==SOLAR EPHEMERIS TO CALCULATE SOLAR ZENITH AND AZIMUTH ANGLES FOR GIVEN DAY, TIME, AND STATION==
;==THE SOLAR EPHEMRIS CALCULATION IS ADOPTED FROM SBDART MODEL (P Ricchiazzi ET AL.)==============
;  AUTHOR:      Paul Ricchiazzi        23oct92
;               Earth Space Research Group,  UCSB
;zensun,day,time,lat,lon,zenith,azimuth,solfac,sunrise=sunrise, $
;           sunset=sunset,local=local,latsun=latsun,lonsun=lonsun
;input
;   day         Julian day (positive scalar or vector)
;   time        Universal Time in hours (scalar or vector)
;   lat         geographic latitude of point on earth's surface (degrees)
;   lon         geographic longitude of point on earth's surface (degrees)
; OUTPUT:
;   zenith      solar zenith angle (degrees)
;   azimuth     solar azimuth  (degrees)
;               Azimuth is measured clockwise from due north
;   solfac      Solar flux multiplier.  SOLFAC=cosine(ZENITH)/RSUN^2
;               where rsun is the current earth-sun distance in
;               astronomical units.
;               NOTE: SOLFAC is negative when the sun is below the horizon
;You can find the details in the code (zensun.pro)

;	LATITUDE AND LONGITUDE OF STATION (AS GIVEN IN THE AERONET DATA FILE)
	alat=38.992
	alon=-76.840

;=====CONVERSION OF AZIMUTH FROM -180 TO 180 FORMAT TO 0 TO 360 FORMAT===
  doy = jday - julday_original(1,0,year1)
  time = hh1 + mn1/60.d + ss1/3600.d   
  zensun,doy,time,alat,alon,fzenith,fazimuth,soldist
  idx360 = where(fazimuth ge -180. and fazimuth lt 0, idx360_cnt)
  if idx360_cnt gt 1 then fazimuth(idx360) = fazimuth(idx360) + 360.D 
;=================================================================================================

;==============================INTERPOLATION======================================================
openw, 8, folder+'fnc8_IDL.txt'
openw, 9, folder+'fnc9_IDL.txt'
openw, 11,folder+'fnc11_IDL.txt'

; MFRSR Raw Data Loop ;fix here 
  for i=0L, nobs-1L do begin
    if tot0(i) gt 0.0 then begin   

        for k =0, 89 do begin
          zenithN(k)=abs(cos_tab(k,0))
          zenithS(k)=abs(cos_tab(k+89,0))
          zenithE(k)=abs(cos_tab(k+179,0))
          zenithW(k)=abs(cos_tab(k+268,0))

          N_CC(k)=cos_tab(k,wv+2)
          S_CC(k)=cos_tab(k+89,wv+2)
          E_CC(k)=cos_tab(k+179,wv+2)
          W_CC(k)=cos_tab(k+268,wv+2)          
        endfor ;k

		    if(fazimuth(i) ge 0. and fazimuth(i) lt 90) then begin
          phi1=0.
          phi2=90.          
		      zenith1=zenithN
		      cc_table1=N_CC
		      zenith2=zenithE
		      cc_table2=E_CC
		    endif

			 if(fazimuth(i) ge 90 and fazimuth(i) lt 180) then begin
          phi1=90.
          phi2=180.          
		      zenith1=zenithE
		      cc_table1=E_CC
		      zenith2=zenithS
		      cc_table2=S_CC
		    endif

		    if(fazimuth(i) ge 180 and fazimuth(i) lt 270) then begin
          phi1=180.
          phi2=270.          
		      zenith1=zenithS
		      cc_table1=S_CC
		      zenith2=zenithW
		      cc_table2=W_CC
        endif

		    if(fazimuth(i) ge 270 and fazimuth(i) lt 360) then begin
          phi1=270.
          phi2=360.
		      zenith1=zenithW
		      cc_table1=W_CC
		      zenith2=zenithN
		      cc_table2=N_CC
		    endif

;================CORRECTION FOR THE TILT=====================================
;Alexandrov et al. (2007), APPLIED OPTICS, Vol. 46, No. 33, 20 November 2007
	zenith_new(i)=acos(cos(fzenith(i)*!DTOR)*cos(tilt_NS*!DTOR)+(sin(fzenith(i)*!DTOR)*sin(tilt_NS*!DTOR)*cos((fazimuth(i)-tilt_EW)*!DTOR)))*!RADEG
	dummy=dir0(i)
  dummy=dummy*cos(sza_i(i)*!DTOR)/cos(zenith_new(i)*!DTOR)	
;================================================================
	fzenith(i)=zenith_new(i)

;	COSINE CORRECTION INTERPOLATION BETWEEN TWO ZENITH ANGLES
ccintptheta1 = interpol(cc_table1,zenith1,fzenith(i))
ccintptheta2 = interpol(cc_table2,zenith2,fzenith(i))

;================INTEPOLATION BETWEEN TWO AZIMUTH ANGLES==============
ccintp=ccintptheta1+(ccintptheta2-ccintptheta1)/(phi2-phi1)*(fazimuth(i)-phi1)

;================COMPUTATION OF CORRECTED VOLTAGES==============
	diff_tot_ratio=dif0(i)/tot0(i)
	v_total=tot0(i)

	vbias=0.0

;       Ft is the composite or total correction factor  
    ft=1./(((1.-diff_tot_ratio)/ccintp)+((diff_tot_ratio-(vbias/v_total))/fdiso(wv)))

  if (tot0(i) gt 0 and fzenith(i) lt 89) then begin
    vt_corr(i)=v_total/ft
    vdiff_corr(i)=dif0(i)/fdiso(wv)
    vdirn_corr(i)=dummy/ccintp
	endif

  if (tot0(i) le 0 or fzenith(i) ge 89) then begin
    vt_corr(i)=0.00
    vdiff_corr(i)=0.00
    vdirn_corr(i)=0.00    
	endif

  if(tot0(i) gt 0 and fzenith(i) lt 89) then begin ;print inputs & ouputs
    printf,8, hh1(i),mn1(i),ss1(i),vt_corr(i),vdiff_corr(i),vdirn_corr(i),sza_i(i),fzenith(i),dummy,cos(sza_i(i)*!DTOR)/cos(zenith_new(i)*!DTOR), format='(3I,7F)'
    printf,9, tot0(i),dif0(i),dir0(i),sza_i(i),ft,fdiso(wv),ccintp, format='(7F)'
    printf,11,month1(i),day1(i),hh1(i),sza_i(i),fzenith(i),zenith_new(i), format='(3I,3F)'
  endif
  
	airmass(i)=1./cos(fzenith(i)*!DTOR)

  endif
  endfor ;End of Loop for UV-MFRSR Data

close, /All
return
end