pro get_chan_spec,ihead,chan,mode,    w_vac,f,err,solv_w,beta_w,alpha_w,gammano2_w

;		INPUT
; ihead - head #
; chan  - channel
; mode  - "screen" or "print"

;		OUTPUT
; w_vac 	- vacuum wavelength for a given chan
; f		-lab measured SRF of the channel
; err		- lab measured SRF error
; solv_w	- spectral ETS at w_vac
; beta_w	- spectral Rayleigh scatering coefficient [atm-1]
; alpha_w	- spectral ozone abs coefficient [atm-cm-1] at w_vac
; gammano2_w 	- spectral NO2 abs coefficient [atm-cm] at w_vac

;       actual central air wavelengths [nm] of MFRSR #271 measured in 2002:
; w_air=[299.758,305.408,311.485,317.638,325.498,332.558,367.906]
;       schifted to vac  wavelengths [nm] of MFRSR #271 (see airvac.pro )
; w_vac=[299.845,305.497,311.575,317.730,325.592,332.654,368.011]

print,'>get_chan_spec:'   

get_xsecV8,l_solv,ml_solv,solv,betv_s,c0v_s,c1v_s,c2v_s	; Get ozone and Rayleigh spectral coefficients interpolated to the ETS solar wavelengths (l_solv)

get_srfw,ihead,chan,w_vac,f,err 		; get SRF of MFRSR #ihead (vac) from the CSU web site
nw_vac=n_elements(w_vac)

;	Interpolate ETS and X-sections to w_vac
solv_w=interpol(solv,l_solv,w_vac)  		; ETS interpolated to SRF vac wavelengths
beta_w=interpol(betv_s,l_solv,w_vac)     	; spectral tau_ray
c0v_w =interpol(c0v_s,l_solv,w_vac)		; ozone: spectral temp coefficients C0
c1v_w =interpol(c1v_s,l_solv,w_vac)
c2v_w =interpol(c2v_s,l_solv,w_vac)
TC=-45.0   ; use alpha(T=-45C) multiplied by measured Total ozone as a first approximation;
alpha_w=c0v_w + c1v_w*TC + c2v_w*TC*TC

;		Read NO2   cross-sections
gammano2_w=dblarr(nw_vac) &  gammano2_w(*)=0.0		; initialize zero NO2 abs coeff [atm-cm-1] at w_vac(nw_vac) outside Van. lab measurements
read_no2,'/misc/userdirs/krotkov/RT/XEFF/no2vand2temp.all',23000,lv_tno2,no2_t       ; read Lab measured no2_t Table NO2 abs coefficient [atm-cm-1]
gammano2_w(*)  = interpol(no2_t,lv_tno2,w_vac )

print,'gammano2_w:'
print,gammano2_w





;		PLOT SRF CHANNEL
no2_temp=1.0		; [DU]
ozone_temp=300.0             ; [DU]
pres_rel_temp=1.000         ; Pressure, atm
airmass_temp=1.0             ; airmass (molecular)

plot_chan_srf,no2_temp,gammano2_w,ihead,ozone_temp,pres_rel_temp,airmass_temp,mode,chan,w_vac,f,err,solv_w,beta_w,alpha_w,$
tau_ray_eff,tau_aer_eff,tau_oz_eff,l_rad		;     SAMPLE OUTPUT

print,'w_vac=' & print,w_vac



return
end
