pro get_tot_cp,no2_aeronet,no2_true,gammano2_w,ctitle,mode,y_input,m_input,d_input,pressure_corr,chan,year_count,time,am,rel_press,ozone_aeronet,ozone_true,$
aeronet_wav_air,aeronet_aot,ifit,cimel_chan,l0_fit,l1_fit,l2_fit, $
w_vac_chen,srf,err_srf,solv_w,beta_w,alpha_w, tr_eff,ta_eff,toz_eff,tno2_eff,tot_eff,l_eff,lam_dir,$
aer340cor,aer380cor,aer440cor,aer500cor, delta_aot_fit,sigma_aot_fit


;	PURPOSE
; calculate effective total extinction optical thickness for selected channel of UV-MFRSR measurement

;	WARNING:
;       12/07/12: Use true measured NO2   in calculating tau_oz
;       12/05/12: Use true measured ozone in calculating tau_oz
;       12/05/12: remove static mode
; 	15/07/11:  add aeronet_wav_air array
;	10/11/09:  No2 correction using fixed Xsec for nomimal spectral channels: 440,305,311,317,325,332,368nm
;	MODIFIED
;	04/25/06 - add Brewer AOT interpolation (linear lsf)                                                                
;	05/20/05 - add 3 wavelength Lagrange interpolation (cimel_chan=3) as opposed to 4 wavelength lsf fit (cimel_chan=4)
;	03/07/05 - V0 correction


;	INPUT
; no2_aeronet   i  AERONET NO2 climatology [DU]
; no2_true      i  True (measured ) NO2    [DU]
; gammano2_w    i  spectral array of No2 abs coefficient [atm-cm-1] at const temperature for given channel (from get_chan_spec.pro)
; mode eq'screen" or 'print' for plot_aot_spec subroutine
; pressure_corr i Obsolete: with V2 AERONET AOT data no pressure correction is needed lolgical Whether to apply pressure correction to AERONET AOT data
; chan 		i character MFRSR spectral channel (car)=['300nm','305nm', ...,'368nm']
; w_vac_chen    i all wavelengths(vac) for the chan   (used only in "dynamic" mode)
; year_count 	i date of measurement=year+doy/365.25
; time		i time 
; am		i airmass 
; rel_press	i P/P0
; ozone_aeronet	i AERONET ozone climatology  [DU]
; ozone_true   	i true measured ozone column (Pandora, OMI)  [DU]
;aeronet_aot(0,1,2,3,4,5,6)	i Aeronet AOT at 340, 380,440,500,670,870,1020 (uncorrected ! )
; ifit          i AERONET spectral extrapolation method (1- linear, 2- quadratic)
; 			(ifit=1  ; linear interpolation/extrapolation lntau vs ln wavelength
;  			(ifit=2  ; quadratic least square regression of  lntau vs ln wavelength
;			alog(w_vac_chen) if  leff_mode eq 'dynamic'
; cimel_chan	i number of AERONET channels in quadratic interpolation
;  		 cimel_chan=4: 2nd order  least squares fit of aeronet ln(tau_aer(340,380,440nm,500nm)) to alog(w_vac_chen)
;  		 cimel_chan=3: Lagrangial  interpolation using just 3 channels: l0_fit,l1_fit,l2_fit    to alog(w_vac_chen)
;							
; l0_fit	i 1st wavelength index in linear fit (ifit=1)  [ 0 ,1  ,2  ,3]
; l1_fit	i 2nd wavelength index in linear fit (ifit=1)  [340,380,440,500]
; l2_fit	i 3d  wavelength index in quadratic  (ifit=2, cimel_chan=3) 
;       	i All 4 CIMEL wavelengths are used for lsf quadratic fit if cimel_chan=4 !
; 

;	OUTPUT
; tr_eff 	o  tau_ray at lam_dir for a given channel (chan)
; ta_eff 	o  estimated AOT at lam_dir for a given channel (chan) applying all corrections to AERONET AOT (ozone and  NO2 only))
; toz_eff 	o  tau_oz at lam_dir for a given channel (chan)
; tno2_eff	o  tau_no2 at lam_dir for a given channel (chan)
; l_eff 	o  band effective wavelength (vac) for channel
; lam_dir 	o  band direct radiance equivalent wavelength (vac) for channel
; aer340cor 	o corrcted aeronet_aot(0)  (for O3, NO2) referred to central wavelength (l_cent) of CIMEL 340nm filter
; aer380cor	o  corrcted aeronet_aot(0)  (for O3, NO2) referred to central wavelength (l_cent) of CIMEL 380nm filter
; aer440cor	o  corrcted aeronet_aot(0)  (for O3, NO2) referred to central wavelength (l_cent) of CIMEL 440nm filter
; aer500cor	o  corrcted aeronet_aot(0)  (for O3, NO2) referred to central wavelength (l_cent) of CIMEL 500nm filter
; delta_aot_fit o difference between linear and quadratic fit
; sigma_aot_fit o standard deviation of AOT quadratic fit

nw_vac=n_elements(w_vac_chen)

e0=int_tabulated(w_vac_chen,solv_w*srf) 		;& print,'Extra atmospheric solar irradiance e0=',e0

tr_chen=rel_press*beta_w    	; Rayleigh at srf vac wavelengths
;print,'Rayleigh' & print,tr_chen

toz_chen=0.001*ozone_true*alpha_w	; True measured Ozone TAU at srf vac wavelengths
delta_ozone= 0.001* (ozone_aeronet - ozone_true )  ; Convert to [atm-cm]

tno2_chen=0.001*no2_true*gammano2_w	; tau NO2 [1] for AERONET NO2 climatology at srf vac wavelengths and fixed temperature: Tno2=??
delta_no2 = 0.001* (no2_aeronet - no2_true )  ;   Convert to [atm-cm]
;print,'get_tot_cp:  no2_aeronet=',no2_aeronet,'	no2_true=',no2_true


;		Calculate aerosol extinction with AERONET AOT gaseous corrections !!! make sure delta_no2 and delta_ozone are in [atm-cm]:
aot_ext,chan,delta_ozone,delta_no2,ctitle,mode,y_input,m_input,d_input,time,am,year_count,pressure_corr,rel_press,ifit,cimel_chan,l0_fit,l1_fit,l2_fit,aeronet_wav_air,aeronet_aot,alog(w_vac_chen),ta_chen,$
aer340cor,aer380cor,aer440cor,aer500cor,delta_aot_fit,sigma_aot_fit

;print,'get_tot_cp: spectral Aerosol'  & print,ta_chen
;print,'Ozone=',ozone
;print,'Pressure=',rel_press

t_spec=exp(-am*(tr_chen + ta_chen +toz_chen + tno2_chen))        ; calculated total spectral transmittance with explicit NO2 AERONET version 2

;print,'t_spec' & print,t_spec
e_bot=int_tabulated(w_vac_chen,t_spec*solv_w*srf)  ;& print,'e_bot=',e_bot
t_meas=double(e_bot/e0)         ; "Measured" bandpass average transmittance
tot_eff=-alog(t_meas)/am	; Effective total optical thickness ;print,'tot_eff',tot_eff

;       Flux weighted (effective) wavelength
l_eff=int_tabulated(w_vac_chen,w_vac_chen*t_spec*solv_w*srf)/e_bot
;;print,'L_eff=',l_eff
; Radiative equivalent wavelength:
l_rad=interpol(double(w_vac_chen),double(t_spec),double(t_meas))
if  abs(l_rad(0)-l_eff) gt 0.5  then begin      ; check closeness to l_eff
;print,'!!! l_rad too far from l_eff !!!'  & print,l_rad(0),l_eff
	for i=1,nw_vac-5 do begin       ; start removing shorter wavelengths iteratively
	l_rad=interpol(double(w_vac_chen(i:nw_vac-1)),double(t_spec(i:nw_vac-1)),double(t_meas)) ;& print,'l_rad,l_eff',i,l_rad(0),l_eff
	if  abs(l_rad(0)-l_eff) le 0.5  then goto,quit  ; quit check l_eff closiness
endfor
print,' !!! Fails to find L_rad: L_rad=L_eff  '
l_rad(0)=l_eff
endif
quit:           ; END L_eff calculation
lam_dir=l_rad(0)  ; & print,'l_rad=',lam_dir 

;	Effective tau at lam_dir
tr_eff=interpol(tr_chen,w_vac_chen,lam_dir) ;&  print,'get_tot_cp: tr_eff=',tr_eff
if tr_eff(0) gt max(tr_chen) or tr_eff(0) lt min(tr_chen) then begin & print,'        !!! tr_eff outside boundaries: ' & print,tr_eff(0),min(tr_chen),max(tr_chen)  & stop & endif


;			Calculate effective tau components as input to RT code 
ta_eff=interpol(ta_chen,w_vac_chen,lam_dir) ;&  print,'get_tot_cp: ta_eff=',ta_eff(0)
if ta_eff(0) gt max(ta_chen) or ta_eff(0) lt min(ta_chen) then begin & print,'        !!! ta_eff(0) outside boundaries !!!' & stop & endif

toz_eff =interpol(toz_chen,w_vac_chen,lam_dir) ;&  print,'toz_eff=',toz_eff(0)
if toz_eff(0) lt min(toz_chen) or toz_eff(0) gt max(toz_chen) then begin & print,'    !!! tau_oz_eff(0) outside boundaries !!!' & stop & endif

tno2_eff =interpol(tno2_chen,w_vac_chen,lam_dir) ;&  print,'get_tot_cp: tno2_eff=',tno2_eff(0)
if tno2_eff(0) lt min(tno2_chen) or tno2_eff(0) gt max(tno2_chen) then begin & print,'    !!! tau_no2_eff(0) outside boundaries !!!' & stop & endif

;print,'toz_eff+ta_eff+tr_eff',toz_eff+ta_eff+tr_eff


return
end
