pro plot_aot_spec,chan,csite,y_input,m_input,d_input,year_count,mode,count_day,time,am,wave_aeronet,aot_aeronet,aer340cor,aer380cor,aer440cor,aer500cor,ifit,    dtau02,sigma_aot_ifit,l0_fit,l1_fit

;  Plot pressure corrected AERONET AOT and spectral interpolations

;	WARNINGS:
;  lam_mfrsr(0) has been changed to 440nm


;		INPUT
; ifit - interpolation polynomial degree: ifit=1 (linear )  ifit=2 (quadratic)

cd_input=string(d_input,format='(i2)') & cm_input=string(m_input,format='(i2)')

x='' 
ctitle='Extrapolated AERONET AOT at'+csite+ string(y_input,format='(i4)')+string(m_input,format='(i5)')+string(d_input,format='(i3)')+string(time,format='(f9.2)')

;		AOT spectral plot
;aot_aer=aot_aeronet					; uncorrected AERONET AOT
aot_aer=[aer340cor,aer380cor,aer440cor,aer500cor]	; corrected AERONET AOT


xleg=340.	; x coordinate to start legend

if mode eq 'screen' then begin
set_plot,'X' ;& device,pseudo_color=8
endif else begin
set_plot,'PS' & device,/color,/landscape,filename='aot_spec'+string(y_input,format='(i4)')+strcompress(cm_input,/remove_all)+strcompress(cd_input,/remove_all)
endelse

;title_plot
;               Blue                    Red
;        0  1   2   3   4   5  6    7   8   9   10  11  12  13  14
;       -30 -25 -20 -15 -10 -5      0  +5  +10 +15 +20 +25 +30 +35
rr = [255,000,000,000,000,100,150,000,255,255,255,255,200,150,000]
gg = [255,000,050,100,150,200,220,240,230,150,100,060,020,000,000]
bb = [255,150,240,255,255,255,255,000,230,150,100,060,020,000,000]
col=[0,2,9,11,13,14]

!p.background=0

tvlct,rr,gg,bb
!p.thick=1
!p.charsize=1.1
!p.charthick=1
!x.thick=3
!y.thick=4



;			PLOT

xct='Wavelength, nm' & xmin=290.  & xmax=550. &  wave=findgen(100)*2 + 290.
aot=wave/wave*1.0 & yct='AERONET extrapolated AOT/AOT(380)'  & ymin=0.5  & ymax=1.8 &  ycv0av=0.50 & ycv0sig=0.50
plot_oo,wave,aot,color=14,/nodata, title=ctitle,$
xticks=2, xtickv=[300.,400.,500.],$
ytitle=yct, yrange=[ymin,ymax],ystyle=1,$
xtitle=xct,xrange=[xmin,xmax],/xs
!p.color=14
xyouts,460,1.50,'Air mass=',size=1.5 & xyouts,510,1.5,string(am,format='(f5.3)' ),size=1.5
;xyouts,350,0.59,'<AOT>=' & xyouts,360.,0.59,string(mean_aot368,format='(f6.3)' )


!p.color=11        ;	original	AERONET
aot_aer_err=[0.02,0.02,0.01,0.01]
;oplot,wave_aeronet,aot_aer,psym=2,sym=1.5
oploterr,wave_aeronet,aot_aer/aot_aer(1),aot_aer_err
xyouts,386,1.0,'!4s!x!d380!n=',charsize=1.5 &  xyouts,400,1.0,string(aot_aer(1),format='(f5.2)'),charsize=1.5

;!p.color=14 & oplot,brewer_wave,brewer_aot/aot_aer(1), psym=2,sym=1.5

;					MFRSR
lam_mfrsr=[440.,305.,311.,340.,325.,332.,380.]  ;    Replaced filters on UV-MFRSR582 are in this order: 440,305,311,340,325,332,380
ln_w_mfrsr=alog(lam_mfrsr)


!p.color=3		; 2nd degree fitted AERONET
ln_aot=alog(aot_aer) & ln_wav=alog(wave_aeronet)
;print,'aot_aer(corr)' & print,aot_aer
;print,'aot_aeronet' & print,aot_aeronet

coe_fit=poly_fit(ln_wav,ln_aot,2,yfit,y_err,sigma_aot_ifit2,corrm,/double)
;print,'2nd degree: coe_fit='	& print,coe_fit
yf =exp(coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav)
oplot,wave_aeronet,yf/aot_aer(1),psym=4,sym=1.0
ln_wav=alog(findgen(120)*2.+280.)
yf =exp(coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav)
oplot,exp(ln_wav),yf/aot_aer(1),line=0             

;		Calculate aot at mfrsr wavelengths using quadratic LSF
yf_mfrsr_2 =exp(coe_fit(0) + coe_fit(1)*ln_w_mfrsr+ coe_fit(2)*ln_w_mfrsr*ln_w_mfrsr)
;print,sigma_aot_fit,aot_aer(1),sigma_aot_ifit2/aot_aer(1)
xyouts,390,0.6,'!4r!ds!n!x/!4s!d380!n!x=' & xyouts,420,0.6,string(sigma_aot_ifit2/aot_aer(1),format='(f5.2)')

!p.color=7		; 1nd degree fitted AERONET atl0_fit and l1_fit	[340,380,440,500]

ln_aot=alog(aot_aer) & ln_wav=alog(wave_aeronet) & linear_fit,ln_wav,ln_aot,[l0_fit,l1_fit],coe_fit,aotm_aer_fit
oplot,wave_aeronet(l0_fit:l1_fit),aotm_aer_fit(l0_fit:l1_fit)/aot_aer(1),psym=6,sym=1.2
alpha=-(ln_aot(l0_fit)-ln_aot(l1_fit) )/(ln_wav(l0_fit)-ln_wav(l1_fit) )		; Angstrom Parameter (slope of the linear fit of lnAOT vs lnWav)

;xyouts,exp(ln_wav(l0_fit)),exp(ln_aot(l0_fit))/aot_aer(1),'!4a!x='  & xyouts,360,1.46,string(alpha,format='(f6.2)')		; alpha[340,380]
xyouts,320,1.5 ,'Angstrom Parameter !4a!x=',size=2 & xyouts,380,1.50,string(alpha,format='(f5.2)'),size=2	;	alpha[380,440]
plots,[exp(ln_wav(l0_fit)),exp(ln_wav(l0_fit))],[ymin,ymax] 
plots,[exp(ln_wav(l1_fit)),exp(ln_wav(l1_fit))],[ymin,ymax] 

ln_wav=alog(findgen(120)*2.+280.)
yf =exp(coe_fit(0) + coe_fit(1)*ln_wav )
oplot,exp(ln_wav),yf/aot_aer(1),line=2            ;	interpolation [340,380]


!p.color=1		; 1st degree fitted AERONET [380,440,500]
ln_aot=alog(aot_aer) & ln_wav=alog(wave_aeronet)
coe_fit=poly_fit(ln_wav(1:3),ln_aot(1:3),1,yfit,y_err,sigma_aot_ifit1,corrm,/double)
yf =exp(coe_fit(0) + coe_fit(1)*ln_wav)
;yf =exp(coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav)
oplot,wave_aeronet(1:3),yf(1:3)/aot_aer(1),psym=4,sym=1.5
i1=1 & i2=2
alpha=-(ln_aot(i1)-ln_aot(i2) )/(ln_wav(i1)-ln_wav(i2) )
;xyouts,385,1.5 ,'!4a!x[380,440]='  & xyouts,410,1.50,string(alpha,format='(f5.2)')	;	alpha[380,440]
ln_wav=alog(findgen(120)*2.+280.)
yf =exp(coe_fit(0) + coe_fit(1)*ln_wav)
;yf =exp(coe_fit(0) + coe_fit(1)*ln_wav+ coe_fit(2)*ln_wav*ln_wav)
oplot,exp(ln_wav),yf/aot_aer(1),line=1             
!p.color=1		; Difference between 1st and 2nd degree fitting at UV-MFRSR wavelengths
yf_mfrsr_1 =exp(coe_fit(0) + coe_fit(1)*ln_w_mfrsr)  ; Calculate aot at mfrsr wavelengths

dtau02=yf_mfrsr_1-yf_mfrsr_2

;               SELECT ONE CHANNEL TO SHOW ON PLOT   

if chan eq '440nm' then begin ; 300nm channel is replaced with 440nm filter
i=0 
end else if chan eq '305nm' then begin
i=1 
end else if chan eq '311nm' then begin
i=2 
end else if chan eq '340nm' then begin
i=3 
end else if chan eq '325nm' then begin
i=4 
end else if chan eq '332nm' then begin
i=5 
end else if chan eq '380nm' then begin
i=6 
end else begin
print,'not a valid channel: ',chan

stop

end
plots,[lam_mfrsr(i),lam_mfrsr(i)],[ymin,ymax] &  xyouts,lam_mfrsr(i),1.3,'Lin-Quad=' & xyouts,lam_mfrsr(i)+30.,1.3,string(dtau02(i),format='(f6.3)'),size=2.0



;			SElect LSF ERROR
IF ifit eq 2 THEN sigma_aot_ifit=sigma_aot_ifit2
IF ifit eq 1 THEN sigma_aot_ifit=sigma_aot_ifit1  
IF ifit ne 1 AND ifit ne 2 THEN BEGIN 
print, 'plot_aot_spec.pro:  ifit not equal to 1 or 2  ifit=:',ifit & stop
ENDIF

!p.color=11

;read,x

if mode ne 'screen' then device,/close
;
return
end
