pro reader_merged_v3, input_filename,$
chan,year,month,day,hour,minute,second,sza,am,$
nm_chan,wav340,wav380,wav440,wav500,wav670,wav870,wav1020,$
aot340,aot380,aot440,aot500,aot670,aot870,aot1020,water,$
pres_true,pres_aeronet,ozone_aeronet,ozone_true,toms_ler,delta_time,delta_time_no2,no2_aeronet,no2_true,errno2

;CODE TO READ THE MONTHLY Merged data with No2 (gsfc.mc.no2.txt)
;AND SELECT  a particular day
;openr,1,'/misc/ground_data/SHADOWBAND/RAW/Goddard/Inst527/gsfc.mc.no2.txt'

;	INPUT
;'enter year,month,day (yyyy,mm,dd) ',y,m,d

; 	WARNINGS
; only process 550000 records

;	MODIFICATIONS
; 11/20/12  Wavelength information is changed in accordance with MFRSR-582
;           The channels of MFRSR-527     was 440,305,312,317,325,332,368 nm
;           But the channels of MFRSR-582 are 440,305,312,340,325,332,380 nm 
; 10/14/11  - delta_time: time difference between AERONET and UV-MFRSR / delta_time_no2: time difference between no2 measurements and UV-MFRSR
; 10/11/11  - preferences (ozone_true,no2_true,delta_time_no2,errno2)
;             O3 : Brewer [ozone_brewer] -> OMI [ozone_omi] -> Pandora [ozone_pandora] -> Climatology [Aeronet]
;             no2: Pandora [no2_pandora] -> Brewer [no2_brewer] -> OMI [no2_omi]  -> Aeronet climatology [no2_aeronet]
; 07/21/11  - Adding OMI no2
; 07/19/11  - Adding wav340,wav380,wav440,wav500,wav670,wav870,wav1020 (exact wavelength)
; 07/11/11  - Adding AOT_675,AOT_870,AOT_1020,Water(cm)
; 04/26/11  - Adding Pressure[hPa],Total_O3[DobsonUnits] and Total_NO2[DobsonUnits] from AERONET file (*.tot15) is  necessary for calibration
; 04/15/11  - To read Jungbin's new merged file
; 05/29/06  - output no2, errno2
; 04/25/06  - output no2deltaT
; 12/29/05  - new version of merged file: /misc/ground_data/SHADOWBAND/RAW/Goddard/Inst527/gsfc.mc.no2.txt
; 05/13/05  - fill missing Brewer by OMI ozone
; 02/18/05  - 300nm channel now aliases to 440nm voltages  !!!!
; 02/18/05  - to process #527 cc  voltages at Mauna Loa (new format with flipped delta_time)
;		see: c:\My Documents\UV-MFRSR527\memo for format example
; 02/03/05  - to process #391 raw voltages at UAE
; 01/18/05  - to process #391 at GSFC
; 11/19/04  - to add new column: delta_time
; 07/18/04  - to include head #391
; 04/30/04  - to include input_filename as input parameter
; 04/15/04  - to give output for only one CIMEL
; 04/10/04  - to give output for only one channel: nm_chan for given input chan
; 02/10/04  - to add TOMS V8 ozone and reflectivity data to the merged dataset
; 09/17/03  - to include AOT500, pressure and ozone data


  openr,1,input_filename

a=' '
readf,1,a		;read header
hdr=a

c=0.& data=strarr(70,550000)
WHILE NOT (EOF(1)) DO BEGIN
    readf,1,a
    x=strsplit (a," ",/extract)
    data(*,c)=x
    c=c+1
ENDWHILE

data=data(*,0:c-1)

year=float(data(2,*))
month=float(data(3,*))
day=float(data(4,*))
hour=float(data(5,*))
minute=float(data(6,*))
second=float(data(7,*))
dhour=hour+minute/60. + second/3600.
;1                  2             3             4              5             6             7  
nm440=fltarr(3,c) & nm305=nm440 & nm311=nm440 & nm340=nm440  & nm325=nm440 & nm332=nm440 & nm380=nm440
nm440(0,*)=float(data(8,*))		;440nm filter!!!
nm440(1,*)=float(data(15,*))
nm440(2,*)=float(data(22,*))

nm305(0,*)=float(data(9,*))
nm305(1,*)=float(data(16,*))
nm305(2,*)=float(data(23,*))

nm311(0,*)=float(data(10,*))
nm311(1,*)=float(data(17,*))
nm311(2,*)=float(data(24,*))

nm340(0,*)=float(data(11,*))
nm340(1,*)=float(data(18,*))
nm340(2,*)=float(data(25,*))

nm325(0,*)=float(data(12,*))
nm325(1,*)=float(data(19,*))
nm325(2,*)=float(data(26,*))

nm332(0,*)=float(data(13,*))
nm332(1,*)=float(data(20,*))
nm332(2,*)=float(data(27,*))

nm380(0,*)=float(data(14,*))
nm380(1,*)=float(data(21,*))
nm380(2,*)=float(data(28,*))

sza       =float(data(30,*))
am        =float(data(32,*)) ;Airmass
wav340    =float(data(34,*)) ;exact wavelength
wav380    =float(data(35,*))
wav440    =float(data(36,*))
wav500    =float(data(37,*))
wav670    =float(data(38,*))
wav870    =float(data(39,*))
wav1020   =float(data(40,*))
aot340    =float(data(41,*))
aot380    =float(data(42,*))
aot440    =float(data(43,*))
aot500    =float(data(44,*))
aot670    =float(data(45,*))
aot870    =float(data(46,*))
aot1020   =float(data(47,*))
water     =float(data(48,*)) ;[cm]
delta_time=float(data(49,*)) ;time difference [min] between MFRSR and AERONET(CIMEL)
pres_true =float(data(50,*)) ;measured pressure


ozone_brewer            =float(data(51,*))
ozone_pandora		=float(data(52,*))
rms_ozone_pandora 	=float(data(53,*))
nrms_ozone_pandora 	=float(data(54,*))
error_ozone_pandora 	=float(data(55,*))

pres_aeronet            =float(data(56,*)) ;pressure from aeronet file (climatological pressure)
ozone_aeronet           =float(data(57,*)) ;ozone from aeronet file (climatological ozone)
no2_aeronet             =float(data(58,*)) ;no2 from aeronet file (climatological no2)

ozone_omi               =float(data(59,*))
toms_ler                =float(data(60,*))
no2_omi                 =float(data(61,*))

no2_brewer		=float(data(62,*))
errno2_brewer		=float(data(63,*))
no2deltaT_brewer_mfrsr	=float(data(64,*)) ; time difference [min] between MFRSR and brewer

no2_pandora		=float(data(65,*))
rms_no2_pandora 	=float(data(66,*))
nrms_no2_pandora 	=float(data(67,*))
errno2_pandora		=float(data(68,*))
no2deltaT_pandora_mfrsr =float(data(69,*)) ; time difference [min] between MFRSR and Pandora

 close,1

;++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
;***ozone_true selection***
;From Gordon
;Pandora has major problems when clouds are present. The ozone goes up 50 to 100DU.
;I am still working on a way to filter the data better so, for now, use the Brewer when we have it, then OMI , then Pandora.

;fill values are -9.99 or 0.00
; Select Best available measured total ozone: Brewer [ozone_brewer] -> OMI [ozone_omi] -> Pandora [ozone_pandora] -> Climatology [Aeronet]
ozone = ozone_brewer ;put Brewer ozone
idx1 = where(ozone le 10,  cnt1)
  if cnt1 gt 0 then begin
    ozone(idx1) = ozone_omi(idx1) ;put OMI ozone
  endif

idx2 = where(ozone le 10., cnt2)
  if cnt2 gt 0 then begin
    ozone(idx2) = ozone_pandora(idx2) ;put pandora ozone
  endif

idx3 = where(ozone le 10, cnt3)
  if cnt3 gt 0 then begin
    ozone(idx3) = ozone_aeronet(idx3) ;put aeronet ozone climatology
  endif
ozone_true=ozone ;(measured + aeronet (climatology))

;***no2_true selection***
; Select Best available measured no2: Pandora [no2_pandora] -> Brewer [no2_brewer] -> OMI [no2_omi]  -> Aeronet climatology [no2_aeronet]
;The Pandora No2 measurement will be the 1st choice IF time difference between Pandora and MFRSR measurement is less than 1 minute. (07/22/2011)
no2 = no2_pandora ;put Pandora no2
err_no2=errno2_pandora
no2delta_time=no2deltaT_pandora_mfrsr

idx1 = where(no2 le 0 or no2deltaT_pandora_mfrsr gt 1, cnt1)
  if cnt1 gt 0 then begin ;Put Brewer no2
    no2(idx1) = no2_brewer(idx1)
    err_no2(idx1) = errno2_brewer(idx1)
    no2delta_time(idx1) = no2deltaT_brewer_mfrsr(idx1)
  endif
idx2 = where(no2 le 0, cnt2)
  if cnt2 gt 0 then begin ;Put OMI no2
    no2(idx2) = no2_omi(idx2)
    err_no2(idx2)  = -9.99  ;Put fill value
    no2delta_time(idx2) = -9.99
  endif
idx3 = where(no2 le 0, cnt3)
  if cnt3 gt 0 then begin ;Put aeronet no2
    no2(idx3) = no2_aeronet(idx3)
    err_no2(idx3) = -9.99
    no2delta_time(idx3) = -9.99
  endif
no2_true=no2 ;(measured + aeronet (climatology))
delta_time_no2 = no2delta_time
errno2 = err_no2
;++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


;		SELECT ONE CHANNEL TO Process

if chan eq '440nm' then begin
;if chan eq '300nm' then begin		; 300nm channel is aliased to 440nm filter
nm_chan=nm440
end else if chan eq '305nm' then begin
nm_chan=nm305
end else if chan eq '311nm' then begin
nm_chan=nm311
end else if chan eq '325nm' then begin
nm_chan=nm325
end else if chan eq '332nm' then begin
nm_chan=nm332
end else if chan eq '340nm' then begin
nm_chan=nm340
end else if chan eq '380nm' then begin
nm_chan=nm380
end else begin
print,'not a valid channel: ',chan
stop

end


return
end
