;		MODIFICATIONS
;         Dec 07  2012  Always do ozone and no2 corrections to AERONET measured AOTs
;         Dec 05  2012  replace AERONET ozone with true ozone in get_total_cp
;         Dec 03  2012  replace measured true pressure with AERONET pressure
;		Sep. 19 2012 V0_NORM format change
;		Jan. 23 2011 update the threshold for the publication  (use SZA <70deg)
;		Oct. 11 2011 update the threshold for the publication  (use SZA <70deg  and AOT (440) > 0.2)
;               Oct. 11 2011 update the reader (delta_time, delta_time_no2)
;               Sep. 7  2011 to update this file based on v0_chan_oneday.pro and previous v0_chan_alldays.pro
;		July 19 2011 to update the reader (in order to add the exact wavelength)
;		July 12 2011 to update the reader
;		July 8 2011: use AERONET pressure, ozone and NO2 to determine V0
;			  BUT save true (measured) pressure, ozone, and NO2 in irradiance file for use in SSA retrievals 
;		June 20   2011: to read new merged file (more things modified by J. Mok)
;		May 4     2011: to read new merged file                 
;	!!!  need using NO2 to increase V0
;		Jul 07-23 2009: add tau_no2 to calibration equation     
;		Jul 07-20 2009: re-calibrate all data GSFC not using NO2
;		Feb 17 2008: re-processing whole record before China campaign
;             June 3 2007: V2 AERONET AOT has climatological NO2 surtracted. 
;			So, clim NO2 should be explicitly added to the calibration equation!
;	!!!   Need restricting sza_max =62 with dome?
;             June 1 2007: procesed new UV-MFRSR data with dome and V2 AERONET AOT                                               
;             Apr 30 2007: August 2006 re-procesed with new cosine correction applied                                                                 
;             Nov 08 2006: New cosine correction applied                                                                 
;             May 29 2006: NO2 column,NO2error, NO2 delta_time  added at the end of irradiance file (inversion input
;             Apr 26 2006: Re-calibrate MFRSR using Brewer AOT data   
;		Apr 24 2006: Fill in ozone (London climatology)  when both Brewer and OMI are missing   
;		Feb 09 2006: modify reader_merged_g2.pro routive  to read Brewer AOT data      
;		Feb 09 2006: modify reader_merged_g2.pro routive  to read Brewer AOT data      
;		Jan 11 2006: modify reader_merged_g1.pro routive                               
;		Jan 06 2006: modify to new input format at GSFC                                
;		May 20 2005: add 3 point Lagrangian wavelength interpolation     : cimel_chan=3
;		May 3 2005: process only morning data at Mauna Loa between am=2-3 
;		March 7 2005: V0 correction: daot=(dlnV0)/am
;		March 3 2005: add plot_aot_spec
;		Feb 28 2005: General linear interpolation   
;		Feb 25 2005: add output for average tau_r, pressure , tau_oz, lam_eff, lam_rad and std
;		Feb 18 2005: UV-MFRSR #527 : include 440nm filter 
;		Feb 18 2005: UV-MFRSR #527 : Mauna Loa data
;		Feb 11 2005: diffuse voltage correction for scattered light into FOV (~8deg FA)
;				assume that diffuse correction does not depend on SZA

mode='screen'		; screen output
;mode='print'		; PostScrip output

csite='GSFC'		; measurement site name
mfrsr_nm=582		; MFRSR optical head number 

close,11 & openr,11,'./v0_norm440nmaeronet.clearno2_20121208'
;close,11 & openr,11,'./v0_norm440nmaeronet.clearno2_527' ; based on the measurement of UVMFRSR 527
a=strarr(2) & readf, 11, a ; read header
matchdata = fltarr(31)

		; select calibration settings 
aot_mode='aeronet'	;  Use Aeronet AOT, pressure, ozone and NO2 for MFRSR calibration ( i.e., determining V0 for each good measuerment )
time_tolerance=3.0 	; max time difference between AERONET and UV-MFRSR measurements [min] 
;sza_max=65.0  & sza_min=0.	; use SZA <70deg (Yes. Just drop AERONET retrievals if it has REF -999, and do not use AERONET data for SZA > 70deg.)
sza_max=82.0  & sza_min=0.	; whole solar day     (not restricted )                                                   
;sza_max=70.529  & sza_min=60.	; Airmass range 3 - 2     (also change time 15-21 for Morning Langley calibrations at ML )                          

pressure_corr='no'	; In version 3 no pressure correction is needed for AERONET AOT data (AERONET pressure is correct)
v0_corr='no'		; NO CIMEL AOT correction in version 3(V0)  
leff_mode='dynamic'	; Effective wavelength is re-calculated for each measurement depending on atmospheric parameters

;		Select spectral channel for calibratiion 
;chan='305nm' & ifit=2 & cimel_chan=4 & l0_fit=0 & l1_fit=1   & l2_fit=2 & l3_fit=3         ; lsf quadratic AOT extrapolation using 4 CIMEL wavelengths (340,380,440,500)
;chan='311nm' & ifit=2 & cimel_chan=4 & l0_fit=0 & l1_fit=1   & l2_fit=2 & l3_fit=3         ; lsf quadratic AOT extrapolation using 4 CIMEL wavelengths (340,380,440,500)
;chan='325nm' & ifit=2 & cimel_chan=4 & l0_fit=0 & l1_fit=1   & l2_fit=2 & l3_fit=3         ; lsf quadratic AOT extrapolation using 4 CIMEL wavelengths (340,380,440,500)
;chan='332nm' & ifit=2 & cimel_chan=4 & l0_fit=0 & l1_fit=1   & l2_fit=2 & l3_fit=3         ; lsf quadratic AOT extrapolation using 4 CIMEL wavelengths (340,380,440,500)
;chan='340nm' & ifit=2 & cimel_chan=4 & l0_fit=0 & l1_fit=1   & l2_fit=2 & l3_fit=3         ; lsf quadratic AOT extrapolation using 4 CIMEL wavelengths (340,380,440,500)
;chan='380nm' & ifit=2 & cimel_chan=4 & l0_fit=0 & l1_fit=1   & l2_fit=2 & l3_fit=3         ; lsf quadratic AOT extrapolation using 4 CIMEL wavelengths (340,380,440,500)
chan='440nm'  & ifit=2 & cimel_chan=3 & l0_fit=1 & l1_fit=2   & l2_fit=3        ; Lagrange quadratic AOT extrapolation using 3  CIMEL wavelengths (380,440,500)

;	Typically no user changes are required after this point

;	read existing merged *.final file  
;input_filename='./total527_20120904_created_date.final'	; V3 total merged file (UV-MFRSR 527)
input_filename='./may_IDL_00_00.final'		; V3 total merged file (UV-MFRSR 582)
print,'input 1 to skip reading merged MFRSR/AERONET file and ETS: ' & read,iskip1 &  if iskip1 eq 1 then goto,skip 
reader_merged_v3,input_filename,chan,year,month,day,hour,minute,second,sza,am,nm_chan,wav340,wav380,wav440,wav500,wav670,wav870,wav1020,aot340,aot380,aot440,aot500,aot670,aot870,aot1020,water,pres_true,pres_aeronet,ozone_aeronet,ozone_true,toms_ler,delta_time,delta_time_no2,no2_aeronet,no2_true,errno2
print,'end reading merged file'
skip:  

saveday='y' & cadday='y' 

;		OUTPUT  header
close,4 & openw,4,'v0_norm'+chan+aot_mode+'.clearno2' ;		Output calibration daily (V0) file
header4=  'year mn day gmt1 gmt2 r2   PRES  AOT S_AOT  N0  N1  V0_NORM ln(V0_N) sig  C0   sigmaC0 TAU    -C1   sigma  m1  m2  C0(am)  sigC0(am) sig_fit(am), m1_am, m2_am, NO2_AERONET,NO2_true_mean, NO2_true_std O3_AERONET O3_true'
printf,4,'V0_NORM using AERONET AOT'+chan+' 	and 		         Langley regression' &  printf,4,header4                                                                                                                                                            
close,5 & openw,5,'irradcal'+chan+aot_mode+'.clearno2' ;         Output calibrated and filtered Irradiances for each good measurement 
printf,5,'AERONET calibrated AOT merged file at '+chan
header5=  'Ins year mn day hh mm ss   total   diffuse  dir_nor  V0_RAW  r2    sza    am     abs_pr OZONE  LER  AOT_AER    daot    saot  AOT_MFRSR TAU_RAY  TAU_OZ  TAU_TOT  L_DIR   L_eff    NO2, NO2err, NO2delta_time   NO2_aeronet'
;printf,5,header5

;		GET MFRSR SECTRAL BAND MODEL FOR SPECIFIC MFRSR HEAD AND SELECTED CHANNEL
get_chan_spec,mfrsr_nm,chan,mode, w_vac_chan,srf,err_srf,solv_w,beta_w,alpha_w,gammano2_w  ; SECTRAL BAND MODEL FOR for specific head and channel

		next_day:			; Start processing next day                         
;read,'enter year,month,day (yyyy,mm,dd) ',y_input,m_input,d_input
readf,11,matchdata &  y_input=matchdata(0) &  m_input=matchdata(1) &  d_input=matchdata(2)

cd_input=string(d_input,format='(i2)') & cm_input=string(m_input,format='(i2)') 
;name_aot   ='aot'+chan+string(y_input,format='(i4)')+strcompress(cm_input,/remove_all)+strcompress(cd_input,/remove_all)
name_langley='langley'+chan+string(y_input,format='(i4)')+strcompress(cm_input,/remove_all)+strcompress(cd_input,/remove_all)
yymmdd=[y_input,m_input,d_input]  & doy=julday(yymmdd)  & print,'doy=',doy
;       -- correct for sun-earth distance
;       V0_RAW = V0_NORM / r2 : see /misc/jwscr1/krotkov/UVFLUX/source_timeseries/uv_flux_can_bsza_V8.f
         phase = 0.0172024238D0 * (double(doy)-3.4)
         r  = 1.0 - 0.0167*cos(phase)
         r2=r*r

year_count_input=double(y_input + doy/365.25)   ;& print,'year_count_input=',year_count_input   ; year count calculation
print,d_input,m_input,y_input
time_all=hour(*)+minute(*)/60.+ second(*)/3600.

; read,'Enter SZA_max(70.529), SZA_min(60): ',sza_max,sza_min   

;gmt_start=15.0 & gmt_end=24.	; Morning only (GMT at ML)
;gmt_start=0.0 & gmt_end=24.	; whole day
;gmt_start=22.5 & gmt_end=23.	; am=1.3


;read,'Enter start time, End Time GMT: ',gmt_start,gmt_end
;	automatic mode time interval selection based on previously calibrated channel (matchdata)
gmt_start=matchdata(3) & gmt_end=matchdata(4)

w=where (       (day eq d_input  )         $			; process only one GMT day at GSFC
            and (month eq m_input) and (year eq y_input) $
            and delta_time(*) le time_tolerance   $
            and nm_chan(2,*) gt 0.0   	   $			; direct voltage ne fill value
            and time_all(*) ge gmt_start   $
            and time_all(*) le gmt_end     $
            and sza(*) ge sza_min	   $
            and sza(*) le sza_max, count_day) &  print,'Number of daily data=',count_day
  if (count_day lt 5) then begin & print,'Number of daily data less than 5' &  goto,next_day &  endif

   time1=hour(w)+minute(w)/60.+ second(w)/3600.		; define fractional decimal hour

  year1=year(w)  & day1=day(w) & month1=month(w) &  hh1=hour(w) & mn1=minute(w) & ss1=second(w)

  aot3401=aot340(w) &  aot3801=aot380(w) &  aot4401=aot440(w) & aot5001=aot500(w) &  aot6701=aot670(w) &  aot8701=aot870(w) &  aot10201=aot1020(w) &  water1  =water(w)

temp_aot3401=moment(aot3401) & mean_aot340=temp_aot3401(0)  & sigma_aot340=sqrt(temp_aot3401(1)) &  print,'Mean daily aot340 : ',mean_aot340,'	St deviation: ',sigma_aot340
temp_aot3801=moment(aot3801) & mean_aot380=temp_aot3801(0)  & sigma_aot380=sqrt(temp_aot3801(1)) &  print,'Mean daily aot380 : ',mean_aot380,'	St deviation: ',sigma_aot380
temp_aot4401=moment(aot4401) & mean_aot440=temp_aot4401(0)  & sigma_aot440=sqrt(temp_aot4401(1)) & print,'Mean daily aot440 : ',mean_aot440,'	St deviation: ',sigma_aot440
temp_aot5001=moment(aot5001) & mean_aot500=temp_aot5001(0)  & sigma_aot500=sqrt(temp_aot5001(1)) & print,'Mean daily aot500 : ',mean_aot500,'	St deviation: ',sigma_aot500
temp_aot6701=moment(aot6701) & mean_aot670=temp_aot6701(0)  & sigma_aot670=sqrt(temp_aot6701(1)) & print,'Mean daily aot670 : ',mean_aot670,'	St deviation: ',sigma_aot670
temp_aot8701=moment(aot8701) & mean_aot870=temp_aot8701(0)  & sigma_aot870=sqrt(temp_aot8701(1)) & print,'Mean daily aot870 : ',mean_aot870,'	St deviation: ',sigma_aot870
temp_aot10201=moment(aot10201) & mean_aot1020=temp_aot10201(0)  & sigma_aot1020=sqrt(temp_aot10201(1)) & print,'Mean daily aot1020 : ',mean_aot1020,'	St deviation: ',sigma_aot1020
temp_water1=moment(water1) & mean_water=temp_water1(0)  & sigma_water=sqrt(temp_water1(1)) & print,'Mean daily water : ',mean_water,'	St deviation: ',sigma_water

;			NO2 data from measurements and climatology
no2_aeronet1 =no2_aeronet(w)
no2_true1    =no2_true(w)
errno21      =errno2(w)
average_no2_aeronet=moment(no2_aeronet1) & print,'Daily AERONET NO2=',average_no2_aeronet(0),'   StDev=',sqrt(average_no2_aeronet(1) )
average_no2_true   =moment(no2_true1) & print,'Daily measured NO2=',average_no2_true(0) , ' StDev=',sqrt(average_no2_true(1))
average_errno2     =moment(errno21)   & print,'Error measured NO2=',average_errno2(0),'      StDev=',sqrt(average_errno2(1))

;			Pressure data
pres_aeronet1=pres_aeronet(w)
temp_pres_aeronet1=moment(pres_aeronet1) & mean_pres_aeronet=temp_pres_aeronet1(0)  & sigma_pres_aeronet=sqrt(temp_pres_aeronet1(1)) &  print,'Mean daily pres_aeronet : ',mean_pres_aeronet,'	St deviation: ',sigma_pres_aeronet
if mean_pres_aeronet le  950.0  then begin
print,'Incorrect input AERONET surface pressure at GSFC:',pres_aeronet1
read,'Enter pressure manually [mbars]: ', subsitute_pressure
pres_aeronet1(*) =subsitute_pressure
print,'Using substitute pressure:',pres_aeronet1
endif

pres_true1=pres_true(w)
temp_pres_true1=moment(pres_true1) & mean_pres_true=temp_pres_true1(0)  & sigma_pres_true=sqrt(temp_pres_true1(1)) &  print,'Mean daily pres_true : ',mean_pres_true,'	St deviation: ',sigma_pres_true
if mean_pres_true le  950.0  then begin ;when measured pressure is not available or very low
print,'Incorrect input Real surface pressure at GSFC:',pres_true1
;read,'Enter pressure manually [mbars]: ', subsitute_pressure
pres_true1(*) = mean_pres_aeronet ;When there is no real pressure, use AERONET data
print,'Using substitute (AERONET) pressure:', mean_pres_aeronet
endif

rel_pres_aeronet=pres_aeronet1/1013.25		; realtive to standard pressure at sea level
mean_psite = mean_pres_aeronet/1013.25


;		use ozone from AERONET file for V0 calculation
ozone_aeronet1=ozone_aeronet(w) &  temp_ozone_aeronet1=moment(ozone_aeronet1) & mean_ozone_aeronet=temp_ozone_aeronet1(0)  & sigma_ozone_aeronet=sqrt(temp_ozone_aeronet1(1))
print,'year_count_input', N_elements(ozone_aeronet1), '	Mean AERONET daily ozone [DU]: ',mean_ozone_aeronet,'	St deviation: ',sigma_ozone_aeronet
ozone_true1=ozone_true(w)    &  temp_ozone_true1=moment(ozone_true1) & mean_ozone_true=temp_ozone_true1(0)  & sigma_ozone_true=sqrt(temp_ozone_true1(1))
print,'year_count_input', N_elements(ozone_true1), '	Mean measured      ozone [DU]: ',mean_ozone_true,'	St deviation: ',sigma_ozone_true

toms_ler1=0.01*toms_ler(w) & temp_toms_ler1=moment(toms_ler1) & mean_toms_ler=temp_toms_ler1(0)  & print,'Mean daily toms_ler [DU]: ',mean_toms_ler

;	extract direct_normal irradiance only for specified DOY
  nm_chanb=reform(nm_chan(2,w)) & tot_irrchanb=reform(nm_chan(0,w)) & dif_irrchanb=reform(nm_chan(1,w)) 
  sza1=reform(sza(w)) & am1=reform(am(w)) 

;		??????????????  clean later
   wav340b =reform(wav340(w))  & aot340b =reform(aot340(w))  & aer340cor =aot340b
   wav380b =reform(wav380(w))  & aot380b =reform(aot380(w))  & aer380cor =aot380b
   wav440b =reform(wav440(w))  & aot440b =reform(aot440(w))  & aer440cor =aot440b
   wav500b =reform(wav500(w))  & aot500b =reform(aot500(w))  & aer500cor =aot500b
   wav670b =reform(wav670(w))  & aot670b =reform(aot670(w))  & aer670cor =aot670b
   wav870b =reform(wav870(w))  & aot870b =reform(aot870(w))  & aer870cor =aot870b
   wav1020b=reform(wav1020(w)) & aot1020b=reform(aot1020(w)) & aer1020cor=aot1020b


   delta_time1=reform(delta_time(w))

totchanb=aot380b  	; total chan OT 
aotchanb=aot380b	; chan AOT (AERONET interpolation)
tau_raychanb=aot380b 	; chan Ray OT
tau_ozchanb=aot380b 	; chan ozone OT 
tau_no2chanb=aot380b 	; chan NO2  OT 
lnv0chan=aot340b	; chan ln(V0) data
dif_aot_int=aot380b	; extrapolation difference between 2nd degree and 1st degree AOT extrapolation at 305nm
saot_fit = aot380b	; sigma fit for 2nd degree polynomial fitting
w_dir=aot380b		; direct radiance equivalent wavelength
w_eff=aot380b		; bandpass effective  wavelength


for i=0,n_elements(aot340b)-1 do begin		; Main cycle through MFRSR daily measurements

aeronet_aot    =[aot340b(i),aot380b(i),aot440b(i),aot500b(i),aot670b(i),aot870b(i),aot1020b(i)]
aeronet_wav_air=[wav340b(i),wav380b(i),wav440b(i),wav500b(i),wav670b(i),wav870b(i),wav1020b(i)]

;  interpolation total TAU: T=tau_aer+tau_ray+tau_ozone+ tau_no2 at w_vac_chan

get_tot_cp,no2_aeronet1(i),no2_true1(i),gammano2_w,csite,mode,y_input,m_input,d_input,pressure_corr,chan,year_count_input,time1(i),am1(i),rel_pres_aeronet(i),ozone_aeronet1(i),ozone_true1(i),$
aeronet_wav_air,aeronet_aot,ifit,cimel_chan,l0_fit,l1_fit,l2_fit,v0_corr,$
v0_corr_cimel, w_vac_chan,srf,err_srf,solv_w,beta_w,alpha_w, temp_r,temp_a,temp_oz,temp_no2,temp_tot,leff,l_rad,$
temp_aer340,temp_aer380,temp_aer440, temp_aer500,delta_aot_fit,sigma_aot_fit

aer340cor(i)=temp_aer340 & aer380cor(i)=temp_aer380 & aer440cor(i)=temp_aer440 & aer500cor(i)=temp_aer500	; AERONET pessure corrected AOT


dif_aot_int(i)	=delta_aot_fit(1) ; interpolation difference between quadratic and linear extrapolation at 305nm
saot_fit(i)	=sigma_aot_fit	; sigma fit for 2nd degree polynomial fitting
aotchanb(i)	=temp_a  
tau_raychanb(i)	=temp_r 
tau_ozchanb(i)	=temp_oz
tau_no2chanb(i)	=temp_no2
totchanb(i)	=temp_tot &  w_dir(i)=l_rad & w_eff(i)=leff ;&  print,'temp_a,temp_r,temp_oz,temp_no2,temp_tot,l_rad',temp_a,temp_r,temp_oz,temp_no2,  temp_tot,l_rad

; lnV0 estimation (no corrections or filtering) ;lnv0chan(i)=alog(nm_chanb(i)) + am1(i)*totchanb(i)		;  individual RAW V0 estimates on a given day

;			Diffuse FOV correction of operational (cosine corrected) voltages
;		Determine FOV correction to nm_chanb due to diffuse FOV scattered light
;read,'Input FOV diffuse light correction [P Russel et al JGR2004]: corr_fov=tau(true)/tau(apparent):	',corr_fov
corr_fov=1.0	; NO FOV CORRECTION
vn_oper=nm_chanb(i) & lnvn_oper=alog(vn_oper)              
lnv0chan(i)=lnvn_oper  + am1(i)*totchanb(i)/corr_fov	;  V0 estimoation with diffuse FOV correction: lnV0=lnVn(operational) + m*(tau_tot)/corr_fov
nm_chanb(i)=exp(lnv0chan(i)*(1.0 -corr_fov) + corr_fov*lnvn_oper) ;Direct normal voltage correction:     FOVcorr=exp(lnV0 (1-corr_fov) + corr_fov*lnVn(operational) )



endfor			; end daily cycle


temp_tau_raychanb=moment(tau_raychanb) & mean_temp_r=temp_tau_raychanb(0)  & sigma_temp_r=sqrt(temp_tau_raychanb(1))
temp_tau_ozchanb=moment(tau_ozchanb) & mean_temp_oz=temp_tau_ozchanb(0)  & sigma_temp_oz=sqrt(temp_tau_ozchanb(1))
temp_tau_no2chanb=moment(tau_no2chanb) & mean_temp_no2=temp_tau_no2chanb(0)  & sigma_temp_no2=sqrt(temp_tau_no2chanb(1))

temp_w_dir=moment(w_dir) & mean_l_rad=temp_w_dir(0)  & sigma_l_rad=sqrt(temp_w_dir(1))
temp_w_eff=moment(w_eff) & mean_l_eff=temp_w_eff(0)  & sigma_l_eff=sqrt(temp_w_eff(1))
temp_rel_pres_aeronet=moment(rel_pres_aeronet) & mean_rel_pres_aeronet=temp_rel_pres_aeronet(0)  & sigma_rel_pres_aeronet=sqrt(temp_rel_pres_aeronet(1))

temp_totchanb=moment(totchanb) & mean_totchan=temp_totchanb(0)  & sigma_totchan=sqrt(temp_totchanb(1))
temp_dif_aot_int=moment(dif_aot_int) & mean_dif_aot_int=temp_dif_aot_int(0)  & sigma_dif_aot_int=sqrt(temp_dif_aot_int(1))

print
print,chan
print,'Daily mean statistics'
print,'Mean values:'
print,'Pressure [atm] tau_oz	tau_ray	tau_no2  l_rad	l_eff'
print,mean_rel_pres_aeronet,mean_temp_oz,mean_temp_r,mean_temp_no2, mean_l_rad, mean_l_eff
print,'STD'
print,sigma_rel_pres_aeronet,sigma_temp_oz,sigma_temp_r,sigma_temp_no2,sigma_l_rad,sigma_l_eff
print

;		Raw Langley plot
ctitle_langley='Langley plot at '+chan+', '+csite +string(y_input,format='(i4)')+string(m_input,format='(i5)')+string(d_input,format='(i3)')
;plot_langley,mode,name_langley,ctitle_langley,count_day,r2,sza1,am1,nm_chanb,aotchanb,mean_ozone_aeronet,mean_psite,pres_aeronet1,time1,lnv0chan,totchanb,mean_lnv0chan, sigma_lnv0chan,mean_aotchan,langley_c0chan,sigma_c0chan,langley_c1chan,sigma_c1chan,langley_sigmachan
coe_fit=poly_fit(am1,alog(nm_chanb),1,v_fit,/double) 
;print,'Raw Langley lnV0', coe_fit(0)

;		V0 calibration plot
plot_lnv0_new,csite,sza_min,sza_max,corr_fov,y_input,m_input,d_input,chan,mode,r2,count_day,time_tolerance,delta_time1,sza1,am1,nm_chanb,aotchanb,tau_raychanb,tau_ozchanb,tau_no2chanb,$
mean_ozone_aeronet,mean_toms_ler,mean_psite,rel_pres_aeronet,time1,lnv0chan,totchanb,$
count3,mean_lnv0chan, sigma_lnv0chan,mean_aotchan,langley_c0chan,sigma_c0chan,langley_c1chan,sigma_c1chan,langley_sigmachan,am1_lan,am2_lan,langley_c0chan_am,sigma_c0chan_am,langley_sigmachan_am,am1_am,am2_am,sig_aot_diff,w3,count_w3,aotchan_mfrsr,aot340b,aot380b,aot440b,aot500b

if count_w3 eq -1 then goto,skip_print_day

;		AOT time plot
;plot_aot_time,cimel,v0_corr,v0_corr_cimel,pressure_corr,corr_fov,y_input,m_input,d_input,chan,mode,r2,count_day,time_tolerance,delta_time1,sza1,am1,aotchanb,mean_ozone_aeronet,mean_toms_ler,mean_psite,rel_press,time1,mean_aotchan,sig_aot_diff,w3,aotchan_mfrsr,aot340b,aot380b,aot440b,aot500b,aer340cor,aer380cor,aer440cor,aer500cor


print,langley_c0chan_am+alog(r2),sigma_c0chan_am,langley_sigmachan_am,am1_am,am2_am


print & print & print,header4 ; OUTPUT   V0  file
print,y_input,m_input,d_input,gmt_start,gmt_end,r2,mean_psite,mean_aotchan,sig_aot_diff,count_day,count3,r2*exp(mean_lnv0chan), mean_lnv0chan+alog(r2),sigma_lnv0chan,$
langley_c0chan+alog(r2),sigma_c0chan,mean_totchan,-langley_c1chan,langley_sigmachan,am1_lan,am2_lan,langley_c0chan_am+alog(r2),sigma_c0chan_am,langley_sigmachan_am,am1_am,am2_am,average_no2_aeronet(0),average_no2_true(0),sqrt(average_no2_true(1)),mean_ozone_aeronet,mean_ozone_true,$
format='(i4,2(1x,i2),2(1x,f4.1),4(1x,f5.3),1x,2(1x,i3),2x,i5,3x,f7.3,1x,f7.4,3x,f7.3,1x,f6.4,1x,f6.3,1x,f6.3,1x,f6.4,1x,2(f4.2,1x),f6.3,2(1x,f6.4),6x,2(1x,f3.1),3f7.3,2f7.1 )'
;read,'save results in v0_normchan_clear file? y - yes, n - no:  ', saveday &  
if saveday eq 'n' then goto,next_day 

printf,4,y_input,m_input,d_input,gmt_start,gmt_end,r2,mean_psite,mean_aotchan,sig_aot_diff,count_day,count3,r2*exp(mean_lnv0chan), mean_lnv0chan+alog(r2),sigma_lnv0chan,$
langley_c0chan+alog(r2),sigma_c0chan,mean_totchan,-langley_c1chan,langley_sigmachan,am1_lan,am2_lan,langley_c0chan_am+alog(r2),sigma_c0chan_am,langley_sigmachan_am,am1_am,am2_am,average_no2_aeronet(0),average_no2_true(0),sqrt(average_no2_true(1)),mean_ozone_aeronet,mean_ozone_true,$
format='(i4,2(1x,i2),2(1x,f4.1),4(1x,f5.3),1x,2(1x,i3),2x,i5,3x,f7.3,1x,f7.4,3x,f7.3,1x,f6.4,1x,f6.3,1x,f6.3,1x,f6.4,1x,2(f4.2,1x),f6.3,2(1x,f6.4),6x,2(1x,f3.1),3f7.3,2f7.1 )'

;     OUTPUT  irradiances file
count_day_good=n_elements(w3)
for i=0,count_day_good-1  do begin    ; print cycle through MFRSR daily measurements
printf,5,mfrsr_nm,y_input,m_input,d_input,hh1(w3(i)),mn1(w3(i)),ss1(w3(i)),tot_irrchanb(w3(i)),dif_irrchanb(w3(i)),nm_chanb(w3(i)),exp(mean_lnv0chan),r2,sza1(w3(i)),am1(w3(i)),pres_true1(w3(i)),ozone_true1(w3(i)),mean_toms_ler,aotchanb(w3(i)),dif_aot_int(w3(i)),saot_fit(w3(i)),aotchan_mfrsr(i),tau_raychanb(w3(i)),tau_ozchanb(w3(i)),totchanb(w3(i)),w_dir(w3(i)),w_eff(w3(i)),no2_true1(w3(i)),errno2(w3(i)),delta_time_no2(w3(i)),no2_aeronet1(w3(i)),$
 format='(2(i4,1x),5(i2,1x),4(f8.2,1x),f5.3,1x,f6.3,1x,f6.4,1x,f7.2,1x,f5.1,1x,f5.2,1x,4(f7.4,1x),3(f8.6,1x),6(f8.4,1x))'

print,mfrsr_nm,y_input,m_input,d_input,hh1(w3(i)),mn1(w3(i)),ss1(w3(i)),tot_irrchanb(w3(i)),dif_irrchanb(w3(i)),nm_chanb(w3(i)),exp(mean_lnv0chan),r2,sza1(w3(i)),am1(w3(i)),pres_true1(w3(i)),ozone_true1(w3(i)),mean_toms_ler,aotchanb(w3(i)),dif_aot_int(w3(i)),saot_fit(w3(i)),aotchan_mfrsr(i),tau_raychanb(w3(i)),tau_ozchanb(w3(i)),totchanb(w3(i)),w_dir(w3(i)),w_eff(w3(i)),no2_true1(w3(i)),errno2(w3(i)),delta_time_no2(w3(i)),no2_aeronet1(w3(i)),$
 format='(2(i4,1x),5(i2,1x),4(f8.2,1x),f5.3,1x,f6.3,1x,f6.4,1x,f7.2,1x,f5.1,1x,f5.2,1x,4(f7.4,1x),3(f8.6,1x),6(f8.4,1x))'


endfor

skip_print_day:

;read,'input additional day: y - yes, n - no:  ', cadday 
 if cadday eq 'y' then goto,next_day & close,4 & close,5

close, /all
stop
end
